/*
 * haar.h
 *
 * The HRLib, simple Haar wavelet-based lossy image compression library.
 * This code is a public domain and was written mostly for simplicity.
 * You can freely modify and redistribute it.
 * 
 * (C) ENTROPYWARE, Alexander Simakov.
 *
 * Our site: http://www.entropyware.info/
 * Support:  support@entropyware.info
 * Author:   xander@entropyware.info
 */

#ifndef HAAR_H
#define HAAR_H

#ifdef HR_WIN32_DLL
#define HR_API __stdcall
#else
#define HR_API
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 * The Haar compression library provides in-memory compression and
 * decompression functions. Compression (decompression) is done in
 * a single step (input and output buffers must be large enough).
 */

#define HR_OK (0)           /* work is completed */
#define HR_PARAMS_FAIL (-1) /* parameters are incorrect */
#define HR_MEMORY_FAIL (-2) /* there is not enough memory */

int HR_API hr_compress(unsigned char *image,  /* image to compress */
                       int width,             /* image width */
                       int height,            /* image height */
                       int quality,           /* quality [0..100] */
                       unsigned char *buffer, /* output buffer */
                       int buffer_size,       /* output buffer size */
                       int *compressed_size); /* compressed image size */

int HR_API hr_decompress(unsigned char *buffer, /* input buffer */
                         int buffer_size,       /* input buffer size */
                         unsigned char *image); /* output buffer (for image) */

void HR_API hr_info(unsigned char *buffer, /* input buffer */
                    int *width,            /* image width will be read from the header and put there */
                    int *height);          /* image height will be read from the header and put there */

#ifdef __cplusplus
}
#endif

#endif /* HAAR_H */
